@@ -13,11 +13,12 @@ class PaginatorIteratorAsync(Iterator):
     def __init__(self, transporter, index_name, request_options=None):
         # type: (Transporter, str, Optional[Union[dict, RequestOptions]]) -> None  # noqa: E501
 
-        super(PaginatorIteratorAsync, self).__init__(transporter, index_name,
-                                                     request_options)
+        super(PaginatorIteratorAsync, self).__init__(
+            transporter, index_name, request_options
+        )
         self._data = {
-            'hitsPerPage': 1000,
-            'page': 0,
+            "hitsPerPage": 1000,
+            "page": 0,
         }
 
     def __aiter__(self):
@@ -30,29 +31,26 @@ class PaginatorIteratorAsync(Iterator):
         # type: () -> dict
 
         if self._raw_response:
-            if len(self._raw_response['hits']):
-                hit = self._raw_response['hits'].pop(0)
+            if len(self._raw_response["hits"]):
+                hit = self._raw_response["hits"].pop(0)
 
-                hit.pop('_highlightResult')
+                hit.pop("_highlightResult")
 
                 return hit
 
-            if self._raw_response['nbHits'] < self._data['hitsPerPage']:
+            if self._raw_response["nbHits"] < self._data["hitsPerPage"]:
                 self._raw_response = {}
                 self._data = {
-                    'hitsPerPage': 1000,
-                    'page': 0,
+                    "hitsPerPage": 1000,
+                    "page": 0,
                 }
                 raise StopAsyncIteration
 
         self._raw_response = yield from self._transporter.read(
-            Verb.POST,
-            self.get_endpoint(),
-            self._data,
-            self._request_options
+            Verb.POST, self.get_endpoint(), self._data, self._request_options
         )
 
-        self._data['page'] += 1
+        self._data["page"] += 1
 
         return self.__anext__()
 
@@ -64,7 +62,6 @@ class PaginatorIteratorAsync(Iterator):
 
 
 class ObjectIteratorAsync(Iterator):
-
     def __aiter__(self):
         # type: () -> ObjectIteratorAsync
 
@@ -77,38 +74,36 @@ class ObjectIteratorAsync(Iterator):
         data = {}  # type: dict
 
         if self._raw_response:
-            if len(self._raw_response['hits']):
-                result = self._raw_response['hits'].pop(0)
+            if len(self._raw_response["hits"]):
+                result = self._raw_response["hits"].pop(0)
 
                 return result
 
-            if 'cursor' not in self._raw_response:
+            if "cursor" not in self._raw_response:
                 self._raw_response = {}
                 raise StopAsyncIteration
             else:
-                data['cursor'] = self._raw_response['cursor']
+                data["cursor"] = self._raw_response["cursor"]
 
         self._raw_response = yield from self._transporter.read(
             Verb.POST,
-            '1/indexes/{}/browse'.format(self._index_name),
+            "1/indexes/{}/browse".format(self._index_name),
             data,
-            self._request_options
+            self._request_options,
         )
 
         return (yield from self.__anext__())
 
 
 class SynonymIteratorAsync(PaginatorIteratorAsync):
-
     def get_endpoint(self):
         # type: () -> str
 
-        return '1/indexes/{}/synonyms/search'.format(self._index_name)
+        return "1/indexes/{}/synonyms/search".format(self._index_name)
 
 
 class RuleIteratorAsync(PaginatorIteratorAsync):
-
     def get_endpoint(self):
         # type: () -> str
 
-        return '1/indexes/{}/rules/search'.format(self._index_name)
+        return "1/indexes/{}/rules/search".format(self._index_name)
